zeta_icons library

Zeta Icons.

See Zeta Icons package for details.

For a list of all icons, visit Zeta Icons.

Classes

ZetaIcons
Zeta Icons. Full list of icons can be found at Zeta Icons.
ZetaIllustrations
Illustrations for Zeta Design System.

Constants

icons → const Map<String, IconData>
List of all icons.
iconsRound → const Map<int, IconData>
Lookup map from codePoint to const round IconData. Used to resolve the round variant without creating non-constant IconData, which allows Flutter to tree-shake unused icon fonts.
iconsSharp → const Map<int, IconData>
Lookup map from codePoint to const sharp IconData. Used to resolve the sharp variant without creating non-constant IconData, which allows Flutter to tree-shake unused icon fonts.
illustrationPaths → const Map<String, String>
List of all illustrations paths.
zetaIconsVersion → const String
Current version of Zeta Icons

Properties

illustrations Map<String, SvgPicture>
List of all illustrations.
getter/setter pair